@@ -1,17 +1,17 @@
+import logging
 from datetime import timezone
 from typing import Iterable, Optional
 
-from acron.job import Job
+from acron.job import Job, SimpleJob
 
 
-__all__ = [
-    "__version__",
-    "run",
-    "Job",
-]
+__all__ = ["__version__", "run", "Job", "SimpleJob", "logger"]
 
 
-__version__ = "0.1.14"
+__version__ = "0.2.0"
+
+
+logger = logging.getLogger("acron")
 
 
 async def run(jobs: Iterable[Job], tz: Optional[timezone] = None) -> None:
